@@ -8,6 +8,7 @@
 #' @param nper    Number of periods - monthly
 #' @param pmt     Instalment per period (should be negative)
 #' @param pv      Present value i.e. loan advance (should be positive)
+#' @param fv      Future value i.e. redemption amount
 #' 
 #' @return rate   The effective interest rate per year
 #'
@@ -25,7 +26,8 @@
 #' APR(df$nper,df$pmt,df$pv)
 #' 
 
-APR <- function(nper,pmt,pv) {
-  stopifnot(nper>=1,pmt<0,pv>0)
-  return(((1+ RATE(nper,pmt,pv))^12)-1)
-}
\ No newline at end of file
+APR <- function(nper, pmt, pv, fv = 0) {
+    stopifnot(nper >= 1, pmt < 0, pv > 0)
+    rate <- ((1 + RATE(nper, pmt, pv, fv))^12) - 1
+    return(rate)
+} 
